@@ -145,9 +145,7 @@ GVContactsTable::refreshContacts (const QDateTime &dtUpdate)
                               "?max-results=10000")
                         .arg (strUser);
     if (dtUpdate.isValid ()) {
-        QString strUpdate = dtUpdate.toString ("yyyy-MM-dd")
-                          + "T"
-                          + dtUpdate.toString ("hh:mm:ss");
+        QString strUpdate = dtUpdate.toUTC().toString (Qt::ISODate);
         strUrl += QString ("&updated-min=%1&showdeleted=true").arg (strUpdate);
         bRefreshIsUpdate = true;
     } else {
@@ -176,6 +174,17 @@ GVContactsTable::refreshAllContacts ()
     refreshContacts (dtUpdate);
 }//GVContactsTable::refreshAllContacts
 
+void
+GVContactsTable::mqUpdateContacts(const QDateTime &dtUpdate)
+{
+    CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
+    QDateTime dtLatest;
+    dbMain.getLatestContact (dtLatest);
+    if (dtLatest <= dtUpdate) {
+        refreshContacts (dtLatest);
+    }
+}//GVContactsTable::mqUpdateContacts
+
 void
 GVContactsTable::setUserPass (const QString &strU, const QString &strP)
 {
