@@ -160,7 +160,7 @@ MainWindow::initLogging ()
                         this     , SLOT(onCleanupLogsArray()));
     Q_ASSERT(rv); Q_UNUSED(rv);
 
-    setStatus("Using qgvdial version 0.2.777");
+    setStatus("Using qgvdial version 0.2.778");
 }//MainWindow::initLogging
 
 /** Log information to console and to log file
@@ -2083,9 +2083,19 @@ MainWindow::createVmailPlayer()
     bool rv = connect (
         vmailPlayer, SIGNAL(stateChanged (Phonon::State, Phonon::State)),
         this, SLOT(onVmailPlayerStateChanged(Phonon::State, Phonon::State)));
-    Q_ASSERT(rv); Q_UNUSED(rv);
+    Q_ASSERT(rv);
+    rv = connect (vmailPlayer, SIGNAL(finished ()),
+                  this, SLOT(onVmailPlayerFinished()));
+    Q_ASSERT(rv);
 }//MainWindow::createVmailPlayer
 
+void
+MainWindow::onVmailPlayerFinished()
+{
+    qDebug("Force stop vmail on finished");
+    vmailPlayer->stop ();
+}//MainWindow::onVmailPlayerFinished
+
 void
 MainWindow::onSigCloseVmail()
 {
